package main

import (
	"oc-aggregator/models"
	_ "oc-aggregator/routers"

	"github.com/beego/beego/logs"
	beego "github.com/beego/beego/v2/server/web"
	"github.com/goraz/onion"
)

const defaultConfigFile = "/etc/oc/aggregator.json"
const localConfigFile = "./aggregator.json"

func main() {
	log := logs.NewLogger(10000)
	log.SetLogger("console")

	configFile := ""
	var o *onion.Onion
	l3 := onion.NewEnvLayerPrefix("_", "OCAGGREGATOR_")
	l2, err := onion.NewFileLayer(defaultConfigFile, nil)
	if err == nil {
		logs.Info("Config file found : " + defaultConfigFile)
		configFile = defaultConfigFile
	}
	l1, err := onion.NewFileLayer(localConfigFile, nil)
	if err == nil {
		logs.Info("Local config file found " + localConfigFile + ", overriding default file")
		configFile = localConfigFile
	}
	if configFile == "" {
		logs.Info("No config file found, using env")
		o = onion.New(l3)
	} else if l1 == nil && l2 == nil {
		o = onion.New(l1, l2, l3)
	} else if l1 == nil {
		o = onion.New(l2, l3)
	} else if l2 == nil {
		o = onion.New(l1, l3)
	}

	models.GetConfig().RedisUrl = o.GetStringDefault("redisurl", "localhost:6379")
	models.GetConfig().RedisPassword = o.GetStringDefault("redispassword", "")
	models.GetConfig().ZincUrl = o.GetStringDefault("zincurl", "http://localhost:4080")
	models.GetConfig().ZincLogin = o.GetStringDefault("zinclogin", "admin")
	models.GetConfig().ZincPassword = o.GetStringDefault("zincpassword", "admin")
	models.GetConfig().DiscoveryUrl = o.GetStringDefault("discoveryurl", "http://localhost:8080/oc/")

	if beego.BConfig.RunMode == "dev" {
		beego.BConfig.WebConfig.DirectoryIndex = true
		beego.BConfig.WebConfig.StaticDir["/swagger"] = "swagger"
	}
	beego.Run()
}
